@@ -1,20 +1,20 @@
 package Sah::Schema::color::ansi256;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-03-02'; # DATE
+our $DATE = '2020-03-04'; # DATE
 our $DIST = 'Sah-Schemas-Color'; # DIST
-our $VERSION = '0.009'; # VERSION
+our $VERSION = '0.010'; # VERSION
 
 our $schema = [int => {
     summary => 'ANSI-256 color, an integer number from 0-255',
     min => 0,
     max => 255,
     examples => [
-        {data=>  0, valid=>1},
-        {data=>255, valid=>1},
-        {data=>256, valid=>0},
-        {data=>'black'  , valid=>0}, # not supported yet
-        {data=>'foo'    , valid=>0},
+        {value=>  0, valid=>1},
+        {value=>255, valid=>1},
+        {value=>256, valid=>0},
+        {value=>'black'  , valid=>0}, # not supported yet
+        {value=>'foo'    , valid=>0},
     ],
 }, {}];
 
@@ -33,21 +33,51 @@ Sah::Schema::color::ansi256 - ANSI-256 color, an integer number from 0-255
 
 =head1 VERSION
 
-This document describes version 0.009 of Sah::Schema::color::ansi256 (from Perl distribution Sah-Schemas-Color), released on 2020-03-02.
+This document describes version 0.010 of Sah::Schema::color::ansi256 (from Perl distribution Sah-Schemas-Color), released on 2020-03-04.
 
 =head1 SYNOPSIS
 
+Using with L<Data::Sah>:
+
+ use Data::Sah qw(gen_validator);
+ my $vdr = gen_validator("color::ansi256*");
+ say $vdr->($data) ? "valid" : "INVALID!";
+
+ # Data::Sah can also create a validator to return error message, coerced value,
+ # even validators in other languages like JavaScript, from the same schema.
+ # See its documentation for more details.
+
+Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
+
+ package MyApp;
+ our %SPEC;
+ $SPEC{myfunc} = {
+     v => 1.1,
+     summary => 'Routine to do blah ...',
+     args => {
+         arg1 => {
+             summary => 'The blah blah argument',
+             schema => ['color::ansi256*'],
+         },
+         ...
+     },
+ };
+ sub myfunc {
+     my %args = @_;
+     ...
+ }
+
 Sample data:
 
- 0  # valid
+ undef  # valid
 
- 255  # valid
+ undef  # valid
 
- 256  # INVALID
+ undef  # INVALID
 
- "black"  # INVALID
+ undef  # INVALID
 
- "foo"  # INVALID
+ undef  # INVALID
 
 =head1 HOMEPAGE
 
