@@ -1,9 +1,9 @@
 package Sah::Schema::color::rgb24;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-03-02'; # DATE
+our $DATE = '2020-03-04'; # DATE
 our $DIST = 'Sah-Schemas-Color'; # DIST
-our $VERSION = '0.009'; # VERSION
+our $VERSION = '0.010'; # VERSION
 
 our $schema = [str => {
     summary => 'RGB 24-digit color, a hexdigit e.g. ffcc00', # XXX also allow other forms
@@ -11,11 +11,11 @@ our $schema = [str => {
     'x.completion' => ['colorname'],
     'x.perl.coerce_rules' => ['From_str::rgb24_from_colorname_X_or_code'],
     examples => [
-        {data=>'000000' , valid=>1, res=>'000000'},
-        {data=>'black'  , valid=>1, res=>'000000'},
-        {data=>'FFffcc' , valid=>1, res=>'ffffcc'},
-        {data=>'#FFffcc', valid=>1, res=>'ffffcc'},
-        {data=>'foo'    , valid=>0},
+        {value=>'000000' , valid=>1, res=>'000000'},
+        {value=>'black'  , valid=>1, res=>'000000'},
+        {value=>'FFffcc' , valid=>1, res=>'ffffcc'},
+        {value=>'#FFffcc', valid=>1, res=>'ffffcc'},
+        {value=>'foo'    , valid=>0},
     ],
 }, {}];
 
@@ -34,21 +34,51 @@ Sah::Schema::color::rgb24 - RGB 24-digit color, a hexdigit e.g. ffcc00
 
 =head1 VERSION
 
-This document describes version 0.009 of Sah::Schema::color::rgb24 (from Perl distribution Sah-Schemas-Color), released on 2020-03-02.
+This document describes version 0.010 of Sah::Schema::color::rgb24 (from Perl distribution Sah-Schemas-Color), released on 2020-03-04.
 
 =head1 SYNOPSIS
 
+Using with L<Data::Sah>:
+
+ use Data::Sah qw(gen_validator);
+ my $vdr = gen_validator("color::rgb24*");
+ say $vdr->($data) ? "valid" : "INVALID!";
+
+ # Data::Sah can also create a validator to return error message, coerced value,
+ # even validators in other languages like JavaScript, from the same schema.
+ # See its documentation for more details.
+
+Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
+
+ package MyApp;
+ our %SPEC;
+ $SPEC{myfunc} = {
+     v => 1.1,
+     summary => 'Routine to do blah ...',
+     args => {
+         arg1 => {
+             summary => 'The blah blah argument',
+             schema => ['color::rgb24*'],
+         },
+         ...
+     },
+ };
+ sub myfunc {
+     my %args = @_;
+     ...
+ }
+
 Sample data:
 
- "000000"  # valid, becomes "000000"
+ undef  # valid, becomes "000000"
 
- "black"  # valid, becomes "000000"
+ undef  # valid, becomes "000000"
 
- "FFffcc"  # valid, becomes "ffffcc"
+ undef  # valid, becomes "ffffcc"
 
- "#FFffcc"  # valid, becomes "ffffcc"
+ undef  # valid, becomes "ffffcc"
 
- "foo"  # INVALID
+ undef  # INVALID
 
 =head1 DESCRIPTION
 
